stateful_widget_binder library
Classes
- DisposableController
- An interface for controllers that need to release resources when they are no longer used.
- ListenableController
- A DisposableController that can notify its listeners when it changes.
-
StateController<
T extends StatefulWidgetBinder, C extends DisposableController> - A State class that manages the lifecycle of a DisposableController.
- StatefulWidgetBinder
- A base class for StatefulWidgets that hold a DisposableController.